package com.manalejandro.arjion;

import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.UnknownHostException;

import org.elasticsearch.client.Client;
import org.elasticsearch.client.transport.TransportClient;
import org.elasticsearch.common.settings.Settings;
import org.elasticsearch.common.transport.TransportAddress;
import org.elasticsearch.transport.client.PreBuiltTransportClient;
import org.elasticsearch.xpack.client.PreBuiltXPackTransportClient;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.elasticsearch.core.ElasticsearchOperations;
import org.springframework.data.elasticsearch.core.ElasticsearchTemplate;
import org.springframework.data.elasticsearch.repository.config.EnableElasticsearchRepositories;

@Configuration
@EnableElasticsearchRepositories(basePackages = "com.manalejandro.arjion.repositories")
public class ESConfig {

	@Value("${elasticsearch.host}")
	private String EsHost;

	@Value("${elasticsearch.port}")
	private int EsPort;

	@Value("${elasticsearch.clustername}")
	private String EsClusterName;

	@Value("${elasticsearch.nodename}")
	private String EsNodeName;

	@Value("${arjion.indexName}")
	private String indexName;

	@Value("${arjion.documentType}")
	private String documentType;

	private TransportClient client;
	
	String clusterId = "2be3ffc1fd284a8788906e5022d0cb18"; // Your cluster ID here
	String region = "eu-central-1"; // Your region here
	boolean enableSsl = true;

	@Bean
	public Client client() {
		Settings settings = Settings.builder()
	            .put("client.transport.nodes_sampler_interval", "5s")
	            .put("client.transport.sniff", false)
	            .put("transport.tcp.compress", true)
	            .put("cluster.name", EsClusterName)
	            .put("xpack.security.transport.ssl.enabled", enableSsl)
	            .put("request.headers.X-Found-Cluster", clusterId)
	            .put("xpack.security.user", "elastic:ypRPLpSMYrEQ5Pm5HL6zePWD")
	            .put("xpack.security.transport.ssl.verification_mode", "full")
			    .build();

			String hostname = clusterId + "." + region + ".aws.cloud.es.io";
			// Instantiate a TransportClient and add the cluster to the list of addresses to connect to.
			// Only port 9343 (SSL-encrypted) is currently supported.
			TransportClient client = null;
			try {
				client = new PreBuiltXPackTransportClient(settings)
						.addTransportAddress(new TransportAddress(InetAddress.getByName(hostname), 9343));
			} catch (UnknownHostException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			return client;
	}

	@Bean
	public ElasticsearchOperations elasticsearchTemplate() throws Exception {
		return new ElasticsearchTemplate(client());
	}

	@Bean
	public String indexName() {
		return indexName;
	}

	@Bean
	public String documentType() {
		return documentType;
	}
}
